@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::PERLANCAR;
 
-our $DATE = '2017-02-09'; # DATE
-our $VERSION = '0.55'; # VERSION
+our $DATE = '2017-07-07'; # DATE
+our $VERSION = '0.56'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -29,14 +29,14 @@ sub configure {
         'IfBuilt',
         'MetaJSON',
         'MetaConfig',
-        'GenShellCompletion',
+        #'GenShellCompletion', # 2017-07-07 - disabled because i want to use DZP:StaticInstall to set x_static_install whenever possible. DZP:StaticInstall doesn't allow InstallTool plugins other than from MakeMaker and ModuleBuildTiny
         ['Authority' => {locate_comment=>1}],
         'OurDate',
         'OurDist',
         'PERLANCAR::OurPkgVersion',
         'PodWeaver',
         ['PruneFiles' => {match => ['~$', '^nytprof.*']}],
-        'ReadmeFromPod',
+        'Pod2Readme',
         'Rinci::AddPrereqs',
         'Rinci::AddToDb',
         'Rinci::Validate',
@@ -68,7 +68,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR - Dist::Zilla like PERLANCAR when y
 
 =head1 VERSION
 
-This document describes version 0.55 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2017-02-09.
+This document describes version 0.56 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2017-07-07.
 
 =head1 SYNOPSIS
 
